@@ -12,7 +12,7 @@ WWW     : http://www.xs4all.nl/~waterlan/
 ======================================================================
 = Copyright                                                          =
 ======================================================================
-Copyright (C) 1997-2008 Erwin Waterlander
+Copyright (C) 1997-2010 Erwin Waterlander
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -26,7 +26,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 =======================================================================
 
@@ -1337,6 +1337,7 @@ void scanfile(char *org_dir, char *filename, int ignore_case,
 #ifdef MSDOS
    if ((strlen(org_dir)>1) && (dd_match(org_dir,"[a-z]:*",1)))
    {
+     /* If user searches "c:bin" (a directory "bin" on drive c:) set path_str to "c:*bin" */
      strncpy(path_str,org_dir,2);
      path_str[DD_MAXDRIVE-1] = '\0';
      line_end = org_dir + DD_MAXDRIVE ;
@@ -1972,13 +1973,16 @@ int main(int argc,char** argv)
       strcpy(localedir,LOCALEDIR);
    else
    {
-      if (strlen(ptr) > DD_MAXPATH)
+      if (strlen(ptr) < sizeof(localedir))
+      {
+         strcpy(localedir,ptr);
+         wcd_fixpath(localedir,sizeof(localedir));
+      }
+      else
       {
          fprintf(stderr,_("Wcd: error: Value of environment variable WCDLOCALEDIR is too long.\n"));
-         strcpy(localedir,"");
+         strcpy(localedir,LOCALEDIR);
       }
-      strcpy(localedir,ptr);
-      wcd_fixpath(localedir,sizeof(localedir));
    }
    setlocale (LC_ALL, "");
    bindtextdomain (PACKAGE, localedir);
@@ -2025,8 +2029,15 @@ int main(int argc,char** argv)
       strcat(banfile,BANFILE);
       strcpy(aliasfile,rootdir);
       strcat(aliasfile,ALIASFILE);
-      strcpy(stackfile,rootdir);
-      strcat(stackfile,STACKFILE);
+      if ((ptr = getenv("WCDSTACKFILE")) == NULL)
+      {
+         strcpy(stackfile,rootdir);
+         strcat(stackfile,STACKFILE);
+      }
+      else
+      {
+         strncpy(stackfile,ptr,sizeof(stackfile));
+      }
    }
    else
    {
@@ -2043,8 +2054,15 @@ int main(int argc,char** argv)
       strcpy(extratreefile,EXTRA_TREEFILE);
       strcpy(banfile,BANFILE);
       strcpy(aliasfile,ALIASFILE);
-      strcpy(stackfile,STACK_GO_DRIVE);
-      strcat(stackfile,STACKFILE);
+      if ((ptr = getenv("WCDSTACKFILE")) == NULL)
+      {
+         strcpy(stackfile,STACK_GO_DRIVE);
+         strcat(stackfile,STACKFILE);
+      }
+      else
+      {
+         strncpy(stackfile,ptr,sizeof(stackfile));
+      }
    }
 #else
 
@@ -2076,8 +2094,15 @@ int main(int argc,char** argv)
    strcat(banfile,BANFILE);
    strcpy(aliasfile,rootdir);
    strcat(aliasfile,ALIASFILE);
-   strcpy(stackfile,rootdir);
-   strcat(stackfile,STACKFILE);
+   if ((ptr = getenv("WCDSTACKFILE")) == NULL)
+   {
+      strcpy(stackfile,rootdir);
+      strcat(stackfile,STACKFILE);
+   }
+   else
+   {
+      strncpy(stackfile,ptr,sizeof(stackfile));
+   }
 #endif
 
    strncpy(scandir,rootdir,DD_MAXPATH);
@@ -2240,7 +2265,7 @@ int main(int argc,char** argv)
         printf(_("wcd %s (%s) - Wherever Change Directory\n"),VERSION,VERSION_DATE);
         printf(_("\
 Chdir for Dos and Unix.\n\
-Copyright (C) 1997-2009 Erwin Waterlander\n\
+Copyright (C) 1997-2010 Erwin Waterlander\n\
 Copyright (C) 1994-2002 Ondrej Popp on C3PO\n\
 Copyright (C) 1995-1996 DJ Delorie on _fixpath()\n\
 Copyright (C) 1995-1996 Borja Etxebarria & Olivier Sirol on Ninux Czo Directory\n\
@@ -2266,7 +2291,7 @@ GNU General Public License for more details.\n\n\
 \
 You should have received a copy of the GNU General Public License\n\
 along with this program; if not, write to the Free Software\n\
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.\n"));
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.\n"));
 
 #if defined(UNIX) || defined(WIN32) || defined(OS2)       /* empty wcd.go file */
             empty_wcdgo(go_file,use_GoScript);
